@@ -106,16 +106,20 @@ class BlockingConnection(base_connection.BaseConnection):
         raise NotImplementedError('Connection callbacks not supported in '
                                   'BlockingConnection')
 
-    def add_timeout(self, deadline, callback):
-        """Add the callback to the IOLoop timer to fire after deadline
-        seconds.
+    def add_timeout(self, deadline, callback_method):
+        """Add the callback_method to the IOLoop timer to fire after deadline
+        seconds. Returns a handle to the timeout. Do not confuse with
+        Tornado's timeout where you pass in the time you want to have your
+        callback called. Only pass in the seconds until it's to be called.
 
         :param int deadline: The number of seconds to wait to call callback
-        :param method callback: The callback method
+        :param method callback_method: The callback method
         :rtype: str
 
         """
-        value = {'deadline': time.time() + deadline, 'callback': callback}
+
+        value = {'deadline': time.time() + deadline,
+                 'callback': callback_method}
         timeout_id = hash(frozenset(value))
         self._timeouts[timeout_id] = value
         return timeout_id
